__all__ = ["Polyline", "Plane", "Box", "Line", "CompositeTransform",  "CoordinateManager"]

from .package_version import __version__

from .box.box import Box
from .plane.plane import Plane
from .line.line import Line
from .polyline.polyline import Polyline
from .transform.composite import CompositeTransform
from .transform.coordinate_manager import CoordinateManager



from . import functions as _functions
from .functions import *  # noqa: F401,F403
from .intersections import intersect_segment_with_plane

__all__ = _functions.__all__ + ["intersect_segment_with_plane"]



from . import affine_transform as _affine_transform
from .affine_transform import *  # noqa: F401,F403
from .rodrigues import as_rotation_matrix, rodrigues  # noqa: F401
from .rotation import euler, rotation_from_up_and_look  # noqa: F401

__all__ = [
    "euler",
    "rodrigues",
    "as_rotation_matrix",
    "rotation_from_up_and_look",
] + _affine_transform.__all__
